==> gorilla-notes-0.2.0-20200815.230532-2.jar: public/js/compiled/cljs-runtime/module$node_modules$vega_wordcloud$build$vega_wordcloud.js <==
shadow$provide.module$node_modules$vega_wordcloud$build$vega_wordcloud=function(global$jscomp$0,require,module,exports$jscomp$0){(function(global,factory){"object"===typeof exports$jscomp$0&&"undefined"!==typeof module?factory(exports$jscomp$0,require("module$node_modules$vega_canvas$build$vega_canvas"),require("module$node_modules$vega_dataflow$build$vega_dataflow"),require("module$node_modules$vega_util$build$vega_util"),require("module$node_modules$vega_scale$build$vega_scale"),require("module$node_modules$vega_statistics$build$vega_statistics")):
"function"===typeof define&&define.amd?define("exports vega-canvas vega-dataflow vega-util vega-scale vega-statistics".split(" "),factory):(global=global||self,factory((global.vega=global.vega||{},global.vega.transforms={}),global.vega,global.vega,global.vega,global.vega,global.vega))})(this,function(exports,vegaCanvas,vegaDataflow,vegaUtil,vegaScale,vegaStatistics){function cloud(){function getContext(canvas){canvas.width=canvas.height=1;var ratio=Math.sqrt(canvas.getContext("2d").getImageData(0,
0,1,1).data.length>>2);canvas.width=2048/ratio;canvas.height=2048/ratio;canvas=canvas.getContext("2d");canvas.fillStyle=canvas.strokeStyle="red";canvas.textAlign="center";return{context:canvas,ratio:ratio}}function place(board,tag,bounds){for(var startX=tag.x,startY=tag.y,maxDelta=Math.sqrt(size[0]*size[0]+size[1]*size[1]),s=spiral(size),dt=.5>random()?1:-1,t=-dt,dxdy,dx;dxdy=s(t+=dt);){dx=~~dxdy[0];dxdy=~~dxdy[1];if(Math.min(Math.abs(dx),Math.abs(dxdy))>=maxDelta)break;tag.x=startX+dx;tag.y=startY+
dxdy;if(!(0>tag.x+tag.x0||0>tag.y+tag.y0||tag.x+tag.x1>size[0]||tag.y+tag.y1>size[1])){if(!(dx=!bounds)){a:{dx=size[0];dx>>=5;dxdy=tag.sprite;var w=tag.width>>5;var last=tag.x-(w<<4);for(var sx=last&127,msx=32-sx,h=tag.y1-tag.y0,x=(tag.y+tag.y0)*dx+(last>>5),j=0;j<h;j++){for(var i=last=0;i<=w;i++)if((last<<msx|(i<w?(last=dxdy[j*w+i])>>>sx:0))&board[x+i]){dx=!0;break a}x+=dx}dx=!1}dx=!dx}if(dx&&(!bounds||tag.x+tag.x1>bounds[0].x&&tag.x+tag.x0<bounds[1].x&&tag.y+tag.y1>bounds[0].y&&tag.y+tag.y0<bounds[1].y)){bounds=
tag.sprite;startX=tag.width>>5;startY=size[0]>>5;t=tag.x-(startX<<4);maxDelta=t&127;s=32-maxDelta;dt=tag.y1-tag.y0;t=(tag.y+tag.y0)*startY+(t>>5);for(dxdy=0;dxdy<dt;dxdy++){for(w=dx=0;w<=startX;w++)board[t+w]=board[t+w]|dx<<s|(w<startX?(dx=bounds[dxdy*startX+w])>>>maxDelta:0);t+=startY}tag.sprite=null;return!0}}}return!1}var size=[256,256],text,font,fontSize,fontStyle,fontWeight,rotate,padding,spiral=archimedeanSpiral,words=[],random=Math.random,cloud={layout:function(){for(var contextAndRatio=getContext(vegaCanvas.canvas()),
board=zeroArray((size[0]>>5)*size[1]),bounds=null,n=words.length,i=-1,tags=[],data=words.map(function(d){return{text:text(d),font:font(d),style:fontStyle(d),weight:fontWeight(d),rotate:rotate(d),size:~~(fontSize(d)+1E-14),padding:padding(d),xoff:0,yoff:0,x1:0,y1:0,x0:0,y0:0,hasText:!1,sprite:null,datum:d}}).sort(function(a,b){return b.size-a.size});++i<n;){var d$jscomp$0=data[i];d$jscomp$0.x=size[0]*(random()+.5)>>1;d$jscomp$0.y=size[1]*(random()+.5)>>1;cloudSprite(contextAndRatio,d$jscomp$0,data,
i);d$jscomp$0.hasText&&place(board,d$jscomp$0,bounds)&&(tags.push(d$jscomp$0),bounds?cloudBounds(bounds,d$jscomp$0):bounds=[{x:d$jscomp$0.x+d$jscomp$0.x0,y:d$jscomp$0.y+d$jscomp$0.y0},{x:d$jscomp$0.x+d$jscomp$0.x1,y:d$jscomp$0.y+d$jscomp$0.y1}],d$jscomp$0.x-=size[0]>>1,d$jscomp$0.y-=size[1]>>1)}return tags},words:function(_){return arguments.length?(words=_,cloud):words},size:function(_){return arguments.length?(size=[+_[0],+_[1]],cloud):size},font:function(_){return arguments.length?(font=functor(_),
cloud):font},fontStyle:function(_){return arguments.length?(fontStyle=functor(_),cloud):fontStyle},fontWeight:function(_){return arguments.length?(fontWeight=functor(_),cloud):fontWeight},rotate:function(_){return arguments.length?(rotate=functor(_),cloud):rotate},text:function(_){return arguments.length?(text=functor(_),cloud):text},spiral:function(_){return arguments.length?(spiral=spirals[_]||_,cloud):spiral},fontSize:function(_){return arguments.length?(fontSize=functor(_),cloud):fontSize},padding:function(_){return arguments.length?
(padding=functor(_),cloud):padding},random:function(_){return arguments.length?(random=_,cloud):random}};return cloud}function cloudSprite(contextAndRatio,d,data,di){if(!d.sprite){var c=contextAndRatio.context,ratio=contextAndRatio.ratio;c.clearRect(0,0,2048/ratio,2048/ratio);var y=contextAndRatio=0,maxh=0,n=data.length;for(--di;++di<n;){d=data[di];c.save();c.font=d.style+" "+d.weight+" "+~~((d.size+1)/ratio)+"px "+d.font;var w=c.measureText(d.text+"m").width*ratio;var h=d.size<<1;if(d.rotate){var sr=
Math.sin(d.rotate*cloudRadians),cr=Math.cos(d.rotate*cloudRadians),wcr=w*cr,wsr=w*sr;cr*=h;w=h*sr;w=Math.max(Math.abs(wcr+w),Math.abs(wcr-w))+31>>5<<5;h=~~Math.max(Math.abs(wsr+cr),Math.abs(wsr-cr))}else w=w+31>>5<<5;h>maxh&&(maxh=h);2048<=contextAndRatio+w&&(contextAndRatio=0,y+=maxh,maxh=0);if(2048<=y+h)break;c.translate((contextAndRatio+(w>>1))/ratio,(y+(h>>1))/ratio);d.rotate&&c.rotate(d.rotate*cloudRadians);c.fillText(d.text,0,0);d.padding&&(c.lineWidth=2*d.padding,c.strokeText(d.text,0,0));
c.restore();d.width=w;d.height=h;d.xoff=contextAndRatio;d.yoff=y;d.x1=w>>1;d.y1=h>>1;d.x0=-d.x1;d.y0=-d.y1;d.hasText=!0;contextAndRatio+=w}n=c.getImageData(0,0,2048/ratio,2048/ratio).data;for(wcr=[];0<=--di;)if(d=data[di],d.hasText){w=d.width;c=w>>5;h=d.y1-d.y0;for(ratio=0;ratio<h*c;ratio++)wcr[ratio]=0;contextAndRatio=d.xoff;if(null==contextAndRatio)break;y=d.yoff;wsr=0;sr=-1;for(maxh=0;maxh<h;maxh++){for(ratio=0;ratio<w;ratio++)cr=n[2048*(y+maxh)+(contextAndRatio+ratio)<<2]?1<<31-ratio%32:0,wcr[c*
maxh+(ratio>>5)]|=cr,wsr|=cr;wsr?sr=maxh:(d.y0++,h--,maxh--,y++)}d.y1=d.y0+sr;d.sprite=wcr.slice(0,(d.y1-d.y0)*c)}}}function cloudBounds(bounds,d){var b0=bounds[0];bounds=bounds[1];d.x+d.x0<b0.x&&(b0.x=d.x+d.x0);d.y+d.y0<b0.y&&(b0.y=d.y+d.y0);d.x+d.x1>bounds.x&&(bounds.x=d.x+d.x1);d.y+d.y1>bounds.y&&(bounds.y=d.y+d.y1)}function archimedeanSpiral(size){var e=size[0]/size[1];return function(t){return[e*(t*=.1)*Math.cos(t),t*Math.sin(t)]}}function zeroArray(n){for(var a=[],i=-1;++i<n;)a[i]=0;return a}
function functor(d){return"function"===typeof d?d:function(){return d}}function Wordcloud(params){vegaDataflow.Transform.call(this,cloud(),params)}var cloudRadians=Math.PI/180,spirals={archimedean:archimedeanSpiral,rectangular:function(size){var dx=4*size[0]/size[1],x=0,y=0;return function(t){var sign=0>t?-1:1;switch(Math.sqrt(1+4*sign*t)-sign&3){case 0:x+=dx;break;case 1:y+=4;break;case 2:x-=dx;break;default:y-=4}return[x,y]}}},Output="x y font fontSize fontStyle fontWeight angle".split(" "),Params=
"text font rotate fontSize fontStyle fontWeight".split(" ");Wordcloud.Definition={type:"Wordcloud",metadata:{modifies:!0},params:[{name:"size",type:"number",array:!0,length:2},{name:"font",type:"string",expr:!0,"default":"sans-serif"},{name:"fontStyle",type:"string",expr:!0,"default":"normal"},{name:"fontWeight",type:"string",expr:!0,"default":"normal"},{name:"fontSize",type:"number",expr:!0,"default":14},{name:"fontSizeRange",type:"number",array:"nullable","default":[10,50]},{name:"rotate",type:"number",
expr:!0,"default":0},{name:"text",type:"field"},{name:"spiral",type:"string",values:["archimedean","rectangular"]},{name:"padding",type:"number",expr:!0},{name:"as",type:"string",array:!0,length:7,"default":Output}]};vegaUtil.inherits(Wordcloud,vegaDataflow.Transform).transform=function(_,pulse){function modp(param){param=_[param];return vegaUtil.isFunction(param)&&pulse.modified(param.fields)}!_.size||_.size[0]&&_.size[1]||vegaUtil.error("Wordcloud size dimensions must be non-zero.");var mod=_.modified();
if(mod||pulse.changed(pulse.ADD_REM)||Params.some(modp)){var data=pulse.materialize(pulse.SOURCE).source,layout=this.value,as=_.as||Output,fontSize=_.fontSize||14,range;vegaUtil.isFunction(fontSize)?range=_.fontSizeRange:fontSize=vegaUtil.constant(fontSize);if(range){var fsize=fontSize,sizeScale=vegaScale.scale("sqrt")().domain(vegaUtil.extent(data,fsize)).range(range);fontSize=function(x){return sizeScale(fsize(x))}}data.forEach(function(t){t[as[0]]=NaN;t[as[1]]=NaN;t[as[3]]=0});data=layout.words(data).text(_.text).size(_.size||
[500,500]).padding(_.padding||1).spiral(_.spiral||"archimedean").rotate(_.rotate||0).font(_.font||"sans-serif").fontStyle(_.fontStyle||"normal").fontWeight(_.fontWeight||"normal").fontSize(fontSize).random(vegaStatistics.random).layout();fontSize=layout.size();layout=fontSize[0]>>1;fontSize=fontSize[1]>>1;range=0;for(var n=data.length,w,t$jscomp$0;range<n;++range)w=data[range],t$jscomp$0=w.datum,t$jscomp$0[as[0]]=w.x+layout,t$jscomp$0[as[1]]=w.y+fontSize,t$jscomp$0[as[2]]=w.font,t$jscomp$0[as[3]]=
w.size,t$jscomp$0[as[4]]=w.style,t$jscomp$0[as[5]]=w.weight,t$jscomp$0[as[6]]=w.rotate;return pulse.reflow(mod).modifies(as)}};exports.wordcloud=Wordcloud;Object.defineProperty(exports,"__esModule",{value:!0})})}
//# sourceMappingURL=module$node_modules$vega_wordcloud$build$vega_wordcloud.js.map

==> gorilla-notes-0.5.0-20200922.072747-2.jar: public/js/compiled/cljs-runtime/module$node_modules$vega_wordcloud$build$vega_wordcloud.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$vega_wordcloud$build$vega_wordcloud=function(global$jscomp$0,require,module,exports$jscomp$0){(function(global,factory){"object"===typeof exports$jscomp$0&&"undefined"!==typeof module?factory(exports$jscomp$0,require("module$node_modules$vega_canvas$build$vega_canvas"),require("module$node_modules$vega_dataflow$build$vega_dataflow"),require("module$node_modules$vega_util$build$vega_util"),require("module$node_modules$vega_scale$build$vega_scale"),require("module$node_modules$vega_statistics$build$vega_statistics")):
"function"===typeof define&&define.amd?define("exports vega-canvas vega-dataflow vega-util vega-scale vega-statistics".split(" "),factory):(global=global||self,factory((global.vega=global.vega||{},global.vega.transforms={}),global.vega,global.vega,global.vega,global.vega,global.vega))})(this,function(exports,vegaCanvas,vegaDataflow,vegaUtil,vegaScale,vegaStatistics){function cloud(){function getContext(canvas){canvas.width=canvas.height=1;var ratio=Math.sqrt(canvas.getContext("2d").getImageData(0,
0,1,1).data.length>>2);canvas.width=2048/ratio;canvas.height=2048/ratio;canvas=canvas.getContext("2d");canvas.fillStyle=canvas.strokeStyle="red";canvas.textAlign="center";return{context:canvas,ratio}}function place(board,tag,bounds){for(var startX=tag.x,startY=tag.y,maxDelta=Math.sqrt(size[0]*size[0]+size[1]*size[1]),s=spiral(size),dt=.5>random()?1:-1,t=-dt,dxdy,dx;dxdy=s(t+=dt);){dx=~~dxdy[0];dxdy=~~dxdy[1];if(Math.min(Math.abs(dx),Math.abs(dxdy))>=maxDelta)break;tag.x=startX+dx;tag.y=startY+dxdy;
if(!(0>tag.x+tag.x0||0>tag.y+tag.y0||tag.x+tag.x1>size[0]||tag.y+tag.y1>size[1])){if(!(dx=!bounds)){a:{dx=size[0];dx>>=5;dxdy=tag.sprite;var w=tag.width>>5;var last=tag.x-(w<<4);for(var sx=last&127,msx=32-sx,h=tag.y1-tag.y0,x=(tag.y+tag.y0)*dx+(last>>5),j=0;j<h;j++){for(var i=last=0;i<=w;i++)if((last<<msx|(i<w?(last=dxdy[j*w+i])>>>sx:0))&board[x+i]){dx=!0;break a}x+=dx}dx=!1}dx=!dx}if(dx&&(!bounds||tag.x+tag.x1>bounds[0].x&&tag.x+tag.x0<bounds[1].x&&tag.y+tag.y1>bounds[0].y&&tag.y+tag.y0<bounds[1].y)){bounds=
tag.sprite;startX=tag.width>>5;startY=size[0]>>5;t=tag.x-(startX<<4);maxDelta=t&127;s=32-maxDelta;dt=tag.y1-tag.y0;t=(tag.y+tag.y0)*startY+(t>>5);for(dxdy=0;dxdy<dt;dxdy++){for(w=dx=0;w<=startX;w++)board[t+w]=board[t+w]|dx<<s|(w<startX?(dx=bounds[dxdy*startX+w])>>>maxDelta:0);t+=startY}tag.sprite=null;return!0}}}return!1}var size=[256,256],text,font,fontSize,fontStyle,fontWeight,rotate,padding,spiral=archimedeanSpiral,words=[],random=Math.random,cloud={layout:function(){for(var contextAndRatio=getContext(vegaCanvas.canvas()),
board=zeroArray((size[0]>>5)*size[1]),bounds=null,n=words.length,i=-1,tags=[],data=words.map(function(d){return{text:text(d),font:font(d),style:fontStyle(d),weight:fontWeight(d),rotate:rotate(d),size:~~(fontSize(d)+1E-14),padding:padding(d),xoff:0,yoff:0,x1:0,y1:0,x0:0,y0:0,hasText:!1,sprite:null,datum:d}}).sort(function(a,b){return b.size-a.size});++i<n;){var d$jscomp$0=data[i];d$jscomp$0.x=size[0]*(random()+.5)>>1;d$jscomp$0.y=size[1]*(random()+.5)>>1;cloudSprite(contextAndRatio,d$jscomp$0,data,
i);d$jscomp$0.hasText&&place(board,d$jscomp$0,bounds)&&(tags.push(d$jscomp$0),bounds?cloudBounds(bounds,d$jscomp$0):bounds=[{x:d$jscomp$0.x+d$jscomp$0.x0,y:d$jscomp$0.y+d$jscomp$0.y0},{x:d$jscomp$0.x+d$jscomp$0.x1,y:d$jscomp$0.y+d$jscomp$0.y1}],d$jscomp$0.x-=size[0]>>1,d$jscomp$0.y-=size[1]>>1)}return tags},words:function(_){return arguments.length?(words=_,cloud):words},size:function(_){return arguments.length?(size=[+_[0],+_[1]],cloud):size},font:function(_){return arguments.length?(font=functor(_),
cloud):font},fontStyle:function(_){return arguments.length?(fontStyle=functor(_),cloud):fontStyle},fontWeight:function(_){return arguments.length?(fontWeight=functor(_),cloud):fontWeight},rotate:function(_){return arguments.length?(rotate=functor(_),cloud):rotate},text:function(_){return arguments.length?(text=functor(_),cloud):text},spiral:function(_){return arguments.length?(spiral=spirals[_]||_,cloud):spiral},fontSize:function(_){return arguments.length?(fontSize=functor(_),cloud):fontSize},padding:function(_){return arguments.length?
(padding=functor(_),cloud):padding},random:function(_){return arguments.length?(random=_,cloud):random}};return cloud}function cloudSprite(contextAndRatio,d,data,di){if(!d.sprite){var c=contextAndRatio.context,ratio=contextAndRatio.ratio;c.clearRect(0,0,2048/ratio,2048/ratio);var y=contextAndRatio=0,maxh=0,n=data.length;for(--di;++di<n;){d=data[di];c.save();c.font=d.style+" "+d.weight+" "+~~((d.size+1)/ratio)+"px "+d.font;var w=c.measureText(d.text+"m").width*ratio;var h=d.size<<1;if(d.rotate){var sr=
Math.sin(d.rotate*cloudRadians),cr=Math.cos(d.rotate*cloudRadians),wcr=w*cr,wsr=w*sr;cr*=h;w=h*sr;w=Math.max(Math.abs(wcr+w),Math.abs(wcr-w))+31>>5<<5;h=~~Math.max(Math.abs(wsr+cr),Math.abs(wsr-cr))}else w=w+31>>5<<5;h>maxh&&(maxh=h);2048<=contextAndRatio+w&&(contextAndRatio=0,y+=maxh,maxh=0);if(2048<=y+h)break;c.translate((contextAndRatio+(w>>1))/ratio,(y+(h>>1))/ratio);d.rotate&&c.rotate(d.rotate*cloudRadians);c.fillText(d.text,0,0);d.padding&&(c.lineWidth=2*d.padding,c.strokeText(d.text,0,0));
c.restore();d.width=w;d.height=h;d.xoff=contextAndRatio;d.yoff=y;d.x1=w>>1;d.y1=h>>1;d.x0=-d.x1;d.y0=-d.y1;d.hasText=!0;contextAndRatio+=w}n=c.getImageData(0,0,2048/ratio,2048/ratio).data;for(wcr=[];0<=--di;)if(d=data[di],d.hasText){w=d.width;c=w>>5;h=d.y1-d.y0;for(ratio=0;ratio<h*c;ratio++)wcr[ratio]=0;contextAndRatio=d.xoff;if(null==contextAndRatio)break;y=d.yoff;wsr=0;sr=-1;for(maxh=0;maxh<h;maxh++){for(ratio=0;ratio<w;ratio++)cr=n[2048*(y+maxh)+(contextAndRatio+ratio)<<2]?1<<31-ratio%32:0,wcr[c*
maxh+(ratio>>5)]|=cr,wsr|=cr;wsr?sr=maxh:(d.y0++,h--,maxh--,y++)}d.y1=d.y0+sr;d.sprite=wcr.slice(0,(d.y1-d.y0)*c)}}}function cloudBounds(bounds,d){var b0=bounds[0];bounds=bounds[1];d.x+d.x0<b0.x&&(b0.x=d.x+d.x0);d.y+d.y0<b0.y&&(b0.y=d.y+d.y0);d.x+d.x1>bounds.x&&(bounds.x=d.x+d.x1);d.y+d.y1>bounds.y&&(bounds.y=d.y+d.y1)}function archimedeanSpiral(size){var e=size[0]/size[1];return function(t){return[e*(t*=.1)*Math.cos(t),t*Math.sin(t)]}}function zeroArray(n){for(var a=[],i=-1;++i<n;)a[i]=0;return a}
function functor(d){return"function"===typeof d?d:function(){return d}}function Wordcloud(params){vegaDataflow.Transform.call(this,cloud(),params)}var cloudRadians=Math.PI/180,spirals={archimedean:archimedeanSpiral,rectangular:function(size){var dx=4*size[0]/size[1],x=0,y=0;return function(t){var sign=0>t?-1:1;switch(Math.sqrt(1+4*sign*t)-sign&3){case 0:x+=dx;break;case 1:y+=4;break;case 2:x-=dx;break;default:y-=4}return[x,y]}}},Output="x y font fontSize fontStyle fontWeight angle".split(" "),Params=
"text font rotate fontSize fontStyle fontWeight".split(" ");Wordcloud.Definition={type:"Wordcloud",metadata:{modifies:!0},params:[{name:"size",type:"number",array:!0,length:2},{name:"font",type:"string",expr:!0,"default":"sans-serif"},{name:"fontStyle",type:"string",expr:!0,"default":"normal"},{name:"fontWeight",type:"string",expr:!0,"default":"normal"},{name:"fontSize",type:"number",expr:!0,"default":14},{name:"fontSizeRange",type:"number",array:"nullable","default":[10,50]},{name:"rotate",type:"number",
expr:!0,"default":0},{name:"text",type:"field"},{name:"spiral",type:"string",values:["archimedean","rectangular"]},{name:"padding",type:"number",expr:!0},{name:"as",type:"string",array:!0,length:7,"default":Output}]};vegaUtil.inherits(Wordcloud,vegaDataflow.Transform).transform=function(_,pulse){function modp(param){param=_[param];return vegaUtil.isFunction(param)&&pulse.modified(param.fields)}!_.size||_.size[0]&&_.size[1]||vegaUtil.error("Wordcloud size dimensions must be non-zero.");var mod=_.modified();
if(mod||pulse.changed(pulse.ADD_REM)||Params.some(modp)){var data=pulse.materialize(pulse.SOURCE).source,layout=this.value,as=_.as||Output,fontSize=_.fontSize||14,range;vegaUtil.isFunction(fontSize)?range=_.fontSizeRange:fontSize=vegaUtil.constant(fontSize);if(range){var fsize=fontSize,sizeScale=vegaScale.scale("sqrt")().domain(vegaUtil.extent(data,fsize)).range(range);fontSize=function(x){return sizeScale(fsize(x))}}data.forEach(function(t){t[as[0]]=NaN;t[as[1]]=NaN;t[as[3]]=0});data=layout.words(data).text(_.text).size(_.size||
[500,500]).padding(_.padding||1).spiral(_.spiral||"archimedean").rotate(_.rotate||0).font(_.font||"sans-serif").fontStyle(_.fontStyle||"normal").fontWeight(_.fontWeight||"normal").fontSize(fontSize).random(vegaStatistics.random).layout();fontSize=layout.size();layout=fontSize[0]>>1;fontSize=fontSize[1]>>1;range=0;for(var n=data.length,w,t$jscomp$0;range<n;++range)w=data[range],t$jscomp$0=w.datum,t$jscomp$0[as[0]]=w.x+layout,t$jscomp$0[as[1]]=w.y+fontSize,t$jscomp$0[as[2]]=w.font,t$jscomp$0[as[3]]=
w.size,t$jscomp$0[as[4]]=w.style,t$jscomp$0[as[5]]=w.weight,t$jscomp$0[as[6]]=w.rotate;return pulse.reflow(mod).modifies(as)}};exports.wordcloud=Wordcloud;Object.defineProperty(exports,"__esModule",{value:!0})})}
//# sourceMappingURL=module$node_modules$vega_wordcloud$build$vega_wordcloud.js.map
